@@ -56,6 +56,8 @@ def _handle_response(api_url, response):
             response.content, object_hook=HttpErrorMessage
         )
         error_dict_get = HttpErrorDict.get(response.status_code)
+        if error_dict_get is None:
+            raise ServerError(error_message_.message)
         raise error_dict_get(msg=error_message_.message)
 
 
